==> pointpos_api-0.0.16.tar.gz: test/ingredient_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for IngredientApi
void main() {
  var instance = new IngredientApi();

  group('tests for IngredientApi', () {
    // Create Ingredient
    //
    // Create Ingredient
    //
    //Future<Ingredient> createIngredient(String authorization, String xAPIKey, Ingredient body, { String xPin }) async 
    test('test createIngredient', () async {
      // TODO
    });

    // Delete Ingredient By ID
    //
    // Delete Ingredient By ID
    //
    //Future deleteIngredientByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteIngredientByID', () async {
      // TODO
    });

    // Get Ingredient List
    //
    // Get Ingredient  List
    //
    //Future<List<Ingredient>> findIngredient(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter }) async 
    test('test findIngredient', () async {
      // TODO
    });

    // Get Ingredient By ID
    //
    // Get Ingredient By ID
    //
    //Future<Ingredient> getIngredientByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getIngredientByID', () async {
      // TODO
    });

    // Update Ingredient By ID
    //
    // Update [object Object] By ID
    //
    //Future<Ingredient> updateIngredientByID(String authorization, String xAPIKey, String id, Ingredient body, { String xPin }) async 
    test('test updateIngredientByID', () async {
      // TODO
    });

  });
}

==> pointpos_api-0.2.1.tar.gz: test/ingredient_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for IngredientApi
void main() {
  var instance = new IngredientApi();

  group('tests for IngredientApi', () {
    // Create Ingredient
    //
    // Create Ingredient
    //
    //Future<Ingredient> createIngredient(String authorization, String xAPIKey, Ingredient body, { String xPin }) async 
    test('test createIngredient', () async {
      // TODO
    });

    // Delete Ingredient By ID
    //
    // Delete Ingredient By ID
    //
    //Future deleteIngredientByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteIngredientByID', () async {
      // TODO
    });

    // Get Ingredient List
    //
    // Get Ingredient  List
    //
    //Future<List<Ingredient>> findIngredient(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter, bool withDeleted }) async 
    test('test findIngredient', () async {
      // TODO
    });

    // Get Ingredient By ID
    //
    // Get Ingredient By ID
    //
    //Future<Ingredient> getIngredientByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getIngredientByID', () async {
      // TODO
    });

    // Update Ingredient By ID
    //
    // Update [object Object] By ID
    //
    //Future<Ingredient> updateIngredientByID(String authorization, String xAPIKey, String id, Ingredient body, { String xPin }) async 
    test('test updateIngredientByID', () async {
      // TODO
    });

  });
}
